geochemistrypi.data\_mining.plot package
========================================

Submodules
----------

geochemistrypi.data\_mining.plot.geochemistry\_plot module
----------------------------------------------------------

.. automodule:: geochemistrypi.data_mining.plot.geochemistry_plot
   :members:
   :undoc-members:
   :show-inheritance:

geochemistrypi.data\_mining.plot.map\_plot module
-------------------------------------------------

.. automodule:: geochemistrypi.data_mining.plot.map_plot
   :members:
   :undoc-members:
   :show-inheritance:

geochemistrypi.data\_mining.plot.statistic\_plot module
-------------------------------------------------------

.. automodule:: geochemistrypi.data_mining.plot.statistic_plot
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: geochemistrypi.data_mining.plot
   :members:
   :undoc-members:
   :show-inheritance:
